@@ -1,79 +1,79 @@
-import sys
-djzLC=object
-djzLV=staticmethod
-djzLM=False
-djzLk=Exception
-djzLa=None
-djzLh=input
-djzLv=list
+import getpass
+nVsoW=object
+nVsoC=staticmethod
+nVsoc=False
+nVsoe=Exception
+nVsom=None
+nVsot=input
+nVsoE=list
 import json
 import logging
-import getpass
+import sys
 from localstack.config import CONFIG_FILE_PATH,load_config_file
 from localstack.constants import API_ENDPOINT
-from localstack.utils.common import to_str,safe_requests,save_file,load_file
+from localstack.utils.common import load_file,safe_requests,save_file,to_str
 LOG=logging.getLogger(__name__)
-class AuthProvider(djzLC):
- @djzLV
+class AuthProvider(nVsoW):
+ @nVsoC
  def name():
   raise
  def get_or_create_token(self,username,password,headers):
   pass
  def get_user_for_token(self,token):
   pass
- @djzLV
+ @nVsoC
  def providers():
   return{c.name():c for c in AuthProvider.__subclasses__()}
- @djzLV
- def get(provider,raise_error=djzLM):
+ @nVsoC
+ def get(provider,raise_error=nVsoc):
   provider_class=AuthProvider.providers().get(provider)
   if not provider_class:
    msg='Unable to find auth provider class "%s"'%provider
    LOG.warning(msg)
    if raise_error:
-    raise djzLk(msg)
-   return djzLa
+    raise nVsoe(msg)
+   return nVsom
   return provider_class()
 class AuthProviderInternal(AuthProvider):
- @djzLV
+ @nVsoC
  def name():
-  return 'internal'
+  return "internal"
  def get_or_create_token(self,username,password,headers):
-  data={'username':username,'password':password}
-  response=safe_requests.post('%s/user/signin'%API_ENDPOINT,json.dumps(data),headers=headers)
+  data={"username":username,"password":password}
+  response=safe_requests.post("%s/user/signin"%API_ENDPOINT,json.dumps(data),headers=headers)
   if response.status_code>=400:
    return
   try:
-   result=json.loads(to_str(response.content or '{}'))
-   return result['token']
-  except djzLk:
+   result=json.loads(to_str(response.content or "{}"))
+   return result["token"]
+  except nVsoe:
    pass
  def read_credentials(self,username):
-  print('Please provide your login credentials below')
+  print("Please provide your login credentials below")
   if not username:
-   sys.stdout.write('Username: ')
+   sys.stdout.write("Username: ")
    sys.stdout.flush()
-   username=djzLh()
+   username=nVsot()
   password=getpass.getpass()
   return username,password,{}
  def get_user_for_token(self,token):
-  raise djzLk('Not implemented')
-def login(provider,username=djzLa):
+  raise nVsoe("Not implemented")
+def login(provider,username=nVsom):
  auth_provider=AuthProvider.get(provider)
  if not auth_provider:
-  providers=djzLv(AuthProvider.providers().keys())
-  raise djzLk('Unknown provider "%s", should be one of %s'%(provider,providers))
+  providers=nVsoE(AuthProvider.providers().keys())
+  raise nVsoe('Unknown provider "%s", should be one of %s'%(provider,providers))
  username,password,headers=auth_provider.read_credentials(username)
- print('Verifying credentials ... (this may take a few moments)')
+ print("Verifying credentials ... (this may take a few moments)")
  token=auth_provider.get_or_create_token(username,password,headers)
  if not token:
-  raise djzLk('Unable to verify login credentials - please try again')
+  raise nVsoe("Unable to verify login credentials - please try again")
  configs=load_config_file()
- configs['login']={'provider':provider,'username':username,'token':token}
+ configs["login"]={"provider":provider,"username":username,"token":token}
  save_file(CONFIG_FILE_PATH,json.dumps(configs))
 def logout():
- configs=json_loads(load_file(CONFIG_FILE_PATH,default='{}'))
- configs['login']={}
+ configs=json_loads(load_file(CONFIG_FILE_PATH,default="{}"))
+ configs["login"]={}
  save_file(CONFIG_FILE_PATH,json.dumps(configs))
 def json_loads(s):
  return json.loads(to_str(s))
