@@ -1,26 +1,26 @@
 #!/usr/bin/env python
-psGIf=dict
-psGIj=super
-psGIk=hasattr
-psGID=Exception
-psGIN=object
-psGIK=dir
-psGIe=None
-psGIz=False
-psGIT=True
-psGIS=len
-psGIF=set
+VUmiQ=dict
+VUmij=super
+VUmik=hasattr
+VUmiE=Exception
+VUmiX=object
+VUmiR=dir
+VUmia=None
+VUmiH=False
+VUmiv=True
+VUmiu=len
+VUmiP=set
 import errno
 import socket
 from select import select
-from socket import(AF_INET,AF_INET6,SOCK_STREAM,IPV6_V6ONLY,SO_REUSEADDR,IPPROTO_TCP,IPPROTO_IPV6,TCP_NODELAY,SOL_SOCKET)
-class AttrDict(psGIf):
+from socket import(AF_INET,AF_INET6,IPPROTO_IPV6,IPPROTO_TCP,IPV6_V6ONLY,SO_REUSEADDR,SOCK_STREAM,SOL_SOCKET,TCP_NODELAY)
+class AttrDict(VUmiQ):
  def __init__(self,*args,**kwargs):
-  psGIj(AttrDict,self).__init__(*args,**kwargs)
+  VUmij(AttrDict,self).__init__(*args,**kwargs)
   self.__dict__=self
 def tcp_listen(six,addr,port,blk):
  s=socket.socket(AF_INET6 if six else AF_INET,SOCK_STREAM)
- if six and psGIk(socket,'IPV6_V6ONLY'):
+ if six and VUmik(socket,"IPV6_V6ONLY"):
   s.setsockopt(IPPROTO_IPV6,IPV6_V6ONLY,0)
  s.setsockopt(SOL_SOCKET,SO_REUSEADDR,1)
  s.setsockopt(IPPROTO_TCP,TCP_NODELAY,1)
@@ -37,9 +37,9 @@ def tcp_connect(six,addr,port,blk):
 def safe_close(x):
  try:
   x.close()
- except psGID:
+ except VUmiE:
   pass
-class Server(psGIN):
+class Server(VUmiX):
  def __init__(self,opt,q):
   self.opt=opt
   self.sock=tcp_listen(opt.ip6,opt.bind_addr,opt.bind_port,0)
@@ -51,17 +51,17 @@ class Server(psGIN):
    cl,addr=self.sock.accept()
    cl.setblocking(0)
    self.q.append(Proxy(self.opt,cl,addr))
-class Half(psGIN):
- def __init__(self,opt,sock,addr,psGIK):
+class Half(VUmiX):
+ def __init__(self,opt,sock,addr,VUmiR):
   self.opt=opt
   self.sock=sock
   self.addr=addr
-  self.psGIK=psGIK
-  self.name='peer' if self.psGIK else 'client'
+  self.VUmiR=VUmiR
+  self.name="peer" if self.VUmiR else "client"
   self.queue=[]
-  self.dest=psGIe
-  self.err=psGIe
-  self.ready=psGIz
+  self.dest=VUmia
+  self.err=VUmia
+  self.ready=VUmiH
  def pre_wait(self,rr,r,w,e):
   if self.ready:
    rr.append(self.sock)
@@ -72,18 +72,18 @@ class Half(psGIN):
   if not self.err and self.sock in w and self.queue:
    self.write_some()
   if not self.err and self.sock in r:
-   self.ready=psGIT
+   self.ready=VUmiv
    self.copy()
   return self.err
  def error(self,msg,e):
-  self.err='Error on %s: %s: %s'%(self.name,msg,e)
+  self.err="Error on %s: %s: %s"%(self.name,msg,e)
   return self.err
  def write_some(self):
   try:
    n=self.sock.send(self.queue[0])
-  except psGID as e:
-   return self.error('send error',e)
-  if n!=psGIS(self.queue[0]):
+  except VUmiE as e:
+   return self.error("send error",e)
+  if n!=VUmiu(self.queue[0]):
    self.queue[0]=self.queue[0][n:]
   else:
    del self.queue[0]
@@ -92,25 +92,25 @@ class Half(psGIN):
    buf=self.sock.recv(4096)
   except socket.error as e:
    if e.errno==errno.EWOULDBLOCK:
-    self.ready=psGIz
+    self.ready=VUmiH
     return
-   return self.error('recv socket error',e)
-  except psGID as e:
-   return self.error('recv error',e)
-  if psGIS(buf)==0:
-   return self.error('eof',0)
+   return self.error("recv socket error",e)
+  except VUmiE as e:
+   return self.error("recv error",e)
+  if VUmiu(buf)==0:
+   return self.error("eof",0)
   self.dest.queue.append(buf)
  def close(self):
   safe_close(self.sock)
-class Proxy(psGIN):
+class Proxy(VUmiX):
  def __init__(self,opt,sock,addr):
   self.opt=opt
-  self.cl=Half(opt,sock,addr,'i')
+  self.cl=Half(opt,sock,addr,"i")
   peer=tcp_connect(opt.ip6,opt.addr,opt.port,0)
-  self.peer=Half(opt,peer,addr,'o')
+  self.peer=Half(opt,peer,addr,"o")
   self.cl.dest=self.peer
   self.peer.dest=self.cl
-  self.err=psGIe
+  self.err=VUmia
  def pre_wait(self,rr,r,w,e):
   self.cl.pre_wait(rr,r,w,e)
   self.peer.pre_wait(rr,r,w,e)
@@ -125,10 +125,10 @@ class Proxy(psGIN):
   return self.err
 def server_loop(opt):
  qs=[]
- opt['ip6']=opt.get('ip6',psGIz)
- opt['bind_addr']=opt.get('bind_addr','0.0.0.0')
- opt['addr']=opt.get('addr','127.0.0.1')
- opt['bind_port']=opt.get('bind_port',0)
+ opt["ip6"]=opt.get("ip6",VUmiH)
+ opt["bind_addr"]=opt.get("bind_addr","0.0.0.0")
+ opt["addr"]=opt.get("addr","127.0.0.1")
+ opt["bind_port"]=opt.get("bind_port",0)
  opt=AttrDict(opt)
  qs.append(Server(opt,qs))
  while qs:
@@ -137,16 +137,16 @@ def server_loop(opt):
    q.pre_wait(rr,r,w,e)
   timeo=10.0 if not rr else 0.0
   r,w,e=select(r,w,e,timeo)
-  r=psGIF(r).union(rr)
+  r=VUmiP(r).union(rr)
   for q in qs:
    if q.post_wait(r,w,e):
     qs.remove(q)
 def main():
- opt={'ip6':psGIz,'bind_port':2223,'addr':'192.168.43.191','port':22}
- opt={'ip6':psGIz,'bind_port':48429,'addr':'128.0.100.3','port':22}
- opt={'ip6':psGIz,'port':54237,'bind_addr':'128.0.100.2','bind_port':22}
- opt={'ip6':psGIz,'port':54237,'bind_addr':'192.168.100.3','bind_port':22}
+ opt={"ip6":VUmiH,"bind_port":2223,"addr":"192.168.43.191","port":22}
+ opt={"ip6":VUmiH,"bind_port":48429,"addr":"128.0.100.3","port":22}
+ opt={"ip6":VUmiH,"port":54237,"bind_addr":"128.0.100.2","bind_port":22}
+ opt={"ip6":VUmiH,"port":54237,"bind_addr":"192.168.100.3","bind_port":22}
  server_loop(opt)
-if __name__=='__main__':
+if __name__=="__main__":
  main()
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
